#include <oxstd.h>
#include <oxdraw.h>
#include <oxprob.h>
#import <maximize>
#import <database>
#include <oxfloat.h>
#include <packages/ssfpack/ssfpack_ex.h>    // imports ssfpack which enables the fast filtering and smoothing of state space models
#import  <maxsqp>

static decl mY, iK, iN, iT;			// some globally declared variables


GetStateSpaceForm(const vPar)
	{
	decl mZ, mT, mH, mQ, mInit;
	decl dRho, vA, dLambda, vO, dSk;
	
	vA       = vPar[0:iN-1];						 // loadings

	mZ       = unit(iN) ~ vA; 				     	 // mapping trends + factor to observations 

	mH       = diag(vPar[iN:2*iN-1].^2);			 // variance idiosyncratic 

    mT       = diag(ones(iK-1,1)|vPar[2*iN+iK]);	 // transition matrix trends + factor
	  
	mQ       = diag(vPar[2*iN:2*iN+iK-2].^2 | (1-vPar[2*iN+iK]^2) ) ;	 // variance trends + factor

	mInit    = unit(iK) * 100 ;                      // diffuse initialization for demographic trends 

	mInit[11][11] = 1;          // stationary initialization for common factor
	
	return{mZ, mH, mT, mQ, mInit};
	}
	
	
fLogLik(const vPs,const dFunc, const avScore, const amHessian)
	{
	decl vPar;
	decl mPhi, mOmega, mSigma, mDelta;
	decl mZ, mH, mT, mQ, mInit;
	decl LL, var;

	vPar = vPs[:iN-1] | exp(vPs[iN:2*iN-1]) |  exp(vPs[2*iN:2*iN+iK-1]) | 0.99999*vPs[2*iN+iK]./sqrt(1+vPs[2*iN+iK].^2);		  // retransform parameters	 [a_i, sigma_eps,i , \sigma_\eta,i , \phi] 

	[mZ, mH, mT, mQ, mInit] = GetStateSpaceForm(vPar);	   // get the state space form 
			   
	mPhi   = mT | mZ;									   // SsfPack set up
	mOmega = mQ ~ zeros(iK,iN) | zeros(iN,iK) ~ mH;
	mSigma = mInit | zeros(iK,1)';
			   	
	SsfLikEx(&LL, &var, mY, mPhi, mOmega, mSigma);		   // likelihood

	dFunc[0] = LL/(iN*iT);                                 // rescale likelihood    

	return 1;
	}
	

main()
	{
	// CHANGE THE NAME HERE TO LOAD DIFFERENT PANEL
	
	// Load data
	mY = loadmat("Data\JEI_ori.in7")[1:][]';	                      // Ordering of the demographic groups: f16-25, f25-35,f35-45,f45-55, f55-over, m16-25, m25-35, m35-45, m45-55. m55-over

	// Standardize panel 
	decl mY_q, vMean, vVar;

	mY_q  = mY;
	vMean = meanr(mY_q);
	vVar  = varr(mY_q);
		
	mY    = (mY_q - vMean) ./ sqrt(vVar);                         // standardize

	iN = rows(mY);                                                // dimensions
	iT = columns(mY);
	iK = 12;
	
	decl vPs, dFunc, iP;

	vPs = 0.1 * ones(11,1) | zeros(iN,1) | zeros(iK,1) | 1;		  // starting values parameter estimation [transformed parameters]

//	MaxControl(-1,1,0);
	iP = MaxBFGS(fLogLik,&vPs,&dFunc,0,1);	                      // BFGS optimization routine 
	println(MaxConvergenceMsg(iP));

	// Process results
	decl vPar, mPhi, mOmega, mSigma, mDelta, mZ, mT, mH, mQ, mInit, mStSmo, mFin;

	vPar = vPs[:10] | exp(vPs[11:11+iN-1]) |  exp(vPs[11+iN:11+iN+iK-1]) | 0.99999*vPs[11+iN+iK]./sqrt(1+vPs[11+iN+iK].^2);		 // retransform parameters

	[mZ, mH, mT, mQ, mInit] = GetStateSpaceForm(vPar);			 // get state space form

	println(mZ, mH, mT, mQ, mInit);							     // uncomment to print system matrices
	
	mPhi   = mT | mZ;											 // set-up ssfpack 
	mOmega = mQ ~ zeros(iK,iN) | zeros(iN,iK) ~ mH;
	mSigma = mInit | zeros(iK,1)';

	SsfMomentEstEx(ST_SMO,&mStSmo,mY,mPhi, mOmega, mSigma);		 // compute conditional mean
	
	SetDrawWindow("demographic-specific trends");
	for(decl i=0;i<iK-1;i++)
		{
		DrawTMatrix(i, mStSmo[i][]-1.96*sqrt(mStSmo[i+iK+iN][]),"",1976,2,12,0,1);
		DrawTMatrix(i, mStSmo[i][],"",1976,2,12,0,1);
		DrawTMatrix(i, mStSmo[i][]+1.96*sqrt(mStSmo[i+iK+iN][]),"",1976,2,12,0,1);
		}
	ShowDrawWindow();
	
	SetDrawWindow("common factor");
	DrawTMatrix(0,mStSmo[11][]-1.96*sqrt(mStSmo[11+iK+iN][]),"",1976,2,12,0,1);
	DrawTMatrix(0,mStSmo[11][],"",1976,2,12,0,1);
	DrawTMatrix(0,mStSmo[11][]+1.96*sqrt(mStSmo[11+iK+iN][]),"",1976,2,12,0,1);
	ShowDrawWindow();

	mFin =  vMean + sqrt(vVar) .* (mZ[][11] * mStSmo[11][]);     // rescaled common component 

	println( (mStSmo[11][]-1.96*sqrt(mStSmo[11+iK+iN][]))' ~ mStSmo[11][]' ~ (mStSmo[11][]+1.96*sqrt(mStSmo[11+iK+iN][]))' );


	// CHANGE THE NAME HERE TO STORE DIFFERENT PANEL
	
	savemat("JIEfactors.in7", (vMean + sqrt(vVar) .* (mZ[][11] * mStSmo[11][]) )');		   //Uncomment to save adjusted hazard rates 

	SetDrawWindow("impliedratesJEU");
	for(decl i=0;i<rows(mFin);i++)
		{
		DrawTMatrix(i, mY_q[i][],"",1976,2,12,0,1);
		DrawTMatrix(i, mFin[i][],"",1976,2,12,0,3);
		}
	ShowDrawWindow();
	
	

	}